#ifndef HAD_FNTABLE_H
#define HAD_FNTABLE_H

/*
   This file is automatically created from ``fntable.fn''; don't change
   this file, change ``fntable.fn'' instead.

   Created from:
    $NiH: mkfntab-h.m4,v 1.7 2002/09/16 12:42:38 dillo Exp $
    $NiH: fntable.fn,v 1.22 2002/09/16 12:42:32 dillo Exp $
*/

/* Basic Functions: fn_basic */
void fn_version(char **args);
void fn_redraw(char **args);
void fn_showname(char **args);
void fn_help(char **args);
void fn_lcd(char **args);
void fn_shell(char **args);
void fn_colon(char **args);
void fn_deidle(char **args);
void fn_site(char **args);
void fn_reconnect(char **args);
void fn_response(char **args);
void fn_mkdir(char **args);
void fn_rmdir(char **args);
void fn_prefix(char **args);
void fn_bind(char **args);
void fn_set(char **args);
/* Scrolling Functions: fn_scroll */
void fn_down(char **args);
void fn_up(char **args);
void fn_pg_down(char **args);
void fn_pg_up(char **args);
void fn_goto(char **args);
void fn_isearch(char **args);
/* Selection Functions: fn_select */
void fn_enter_get(char **args);
void fn_enter_view(char **args);
void fn_enter(char **args);
void fn_reload(char **args);
void fn_get(char **args);
void fn_view(char **args);
void fn_pipe(char **args);
void fn_put(char **args);
void fn_cdup(char **args);
void fn_cd(char **args);
void fn_state(char **args);
void fn_leave_tag(char **args);
/* Tagging Functions: fn_tag */
void fn_tag(char **args);
void fn_cleartags(char **args);
void fn_gettags(char **args);
void fn_savetags(char **args);
void fn_loadtag(char **args);
void fn_saveurls(char **args);

#endif /* fntable.h */
